@@ -1,11 +1,9 @@
 """A class and CLI client to interact with a Pyjojo instance"""
-import argparse
+from __future__ import print_function
+
 import base64
 import json
-import os
 import requests
-import sys
-import yaml
 
 
 class Mojo(object):
@@ -43,9 +41,9 @@ class Mojo(object):
             if "http_method" not in script:
                 self.scripts[script]["http_method"] = "POST"
 
-
     def __call(self, path, method="GET", data=""):
         """Makes a call to a Jojo"""
+
         session = requests.Session()
         headers = {"Content-Type": "application/json"}
 
@@ -67,7 +65,6 @@ class Mojo(object):
 
         return response
 
-
     def get_scripts(self, param=None, tags=None):
         """Gets a collection of scripts that live on the Jojo"""
         route = "/scripts"
@@ -82,7 +79,6 @@ class Mojo(object):
 
         return {}
 
-
     def get_script_names(self, param=None, tags=None):
         """Gets a list of script names that live on the Jojo"""
         route = "/script_names"
@@ -92,7 +88,6 @@ class Mojo(object):
         if resp.status_code == 200:
             return resp.json()["script_names"]
 
-
     def reload(self):
         """Reloads the Jojo's script cache, then stashes that data in the
            Mojo"""
@@ -106,7 +101,6 @@ class Mojo(object):
         else:
             return None
 
-
     def get_script(self, name, use_cache=True):
         """Gets data about a script in the Jojo, from the cache or from the
            Jojo"""
@@ -123,7 +117,6 @@ class Mojo(object):
             else:
                 return None
 
-
     def run(self, name, params=None):
         """Runs the named script with the given parameters"""
         data = None
